@@ -40,12 +40,13 @@ try:
 except ImportError:
     from httplib import BadStatusLine
 import socket
+import subprocess
 import re
 import DistUpgrade.DistUpgradeCache
 from gettext import gettext as _
 
 SYNAPTIC_PINFILE = "/var/lib/synaptic/preferences"
-CHANGELOGS_POOL = "http://changelogs.ubuntu.com/changelogs/pool/"
+CHANGELOGS_POOL = "https://changelogs.ubuntu.com/changelogs/pool/"
 CHANGELOGS_URI = CHANGELOGS_POOL + "%s/%s/%s/%s_%s/%s"
 
 
@@ -63,6 +64,8 @@ class MyCache(DistUpgrade.DistUpgradeCache.MyCache):
 
     def __init__(self, progress, rootdir=None):
         apt.Cache.__init__(self, progress, rootdir)
+        # save for later
+        self.rootdir = rootdir
         # raise if we have packages in reqreinst state
         # and let the caller deal with that (runs partial upgrade)
         assert len(self.req_reinstall_pkgs) == 0
@@ -74,11 +77,27 @@ class MyCache(DistUpgrade.DistUpgradeCache.MyCache):
         self._initDepCache()
         self.all_changes = {}
         self.all_news = {}
+        self.pro_versions = {}
         # on broken packages, try to fix via saveDistUpgrade()
         if self._depcache.broken_count > 0:
             self.saveDistUpgrade()
         assert (self._depcache.broken_count == 0 and
                 self._depcache.del_count == 0)
+        # generate versioned_kernel_pkgs_regexp for later use
+        apt_versioned_kernel_pkgs = apt_pkg.config.value_list(
+            "APT::VersionedKernelPackages")
+        if apt_versioned_kernel_pkgs:
+            self.versioned_kernel_pkgs_regexp = re.compile("(" + "|".join(
+                ["^" + p for p in apt_versioned_kernel_pkgs]) + ")")
+            running_kernel_version = subprocess.check_output(
+                ["uname", "-r"], universal_newlines=True).rstrip()
+            self.running_kernel_pkgs_regexp = re.compile("(" + "|".join(
+                [("^" + p + ".*" + running_kernel_version)
+                 if not p.startswith(".*") else (running_kernel_version + p)
+                 for p in apt_versioned_kernel_pkgs]) + ")")
+        else:
+            self.versioned_kernel_pkgs_regexp = None
+            self.running_kernel_pkgs_regexp = None
 
     def _dpkgJournalDirty(self):
         """
@@ -222,7 +241,7 @@ class MyCache(DistUpgrade.DistUpgradeCache.MyCache):
         # and so its possible to do a man-in-the-middle attack to steal the
         # credentials
         res = urlsplit(uri)
-        if res.scheme == "https" and res.username != "":
+        if res.scheme == "https" and res.username:
             raise HttpsChangelogsUnsupportedError(
                 "https locations with username/password are not"
                 "supported to fetch changelogs")
@@ -340,14 +359,22 @@ class MyCache(DistUpgrade.DistUpgradeCache.MyCache):
                         "Please check your Internet connection.")
         self.all_changes[name] += error_message
 
+    # If the machine is not attached to Ubuntu Pro, Update Manager advertises
+    # the upgrades that would be available if it were attached.
+    # As that is unbeknownst to Apt, we need this map to show the correct
+    # version of each upgradable-if-pro-subscribed package.
+    def create_pro_cache(self, pro_pkgs):
+        for (name, version, _a, _a) in pro_pkgs:
+            self.pro_versions[name] = version
+
     def get_changelog(self, name):
         " get the changelog file from the changelog location "
         origins = self[name].candidate.origins
+        version = self.pro_versions.get(name, self[name].candidate.version)
         self.all_changes[name] = _("Changes for %s versions:\n"
                                    "Installed version: %s\n"
                                    "Available version: %s\n\n") % \
-            (name, getattr(self[name].installed, "version", None),
-             self[name].candidate.version)
+            (name, getattr(self[name].installed, "version", None), version)
         if self.CHANGELOG_ORIGIN not in [o.origin for o in origins]:
             self._fetch_changelog_for_third_party_package(name)
             return
