@@ -79,6 +79,16 @@ class ExecutionTime(object):
         print("%s: %s" % (self.info, time.time() - self.now))
 
 
+class SoftwarePropertiesPage():
+    ubuntu_software = 0
+    other_software = 1
+    updates = 2
+    authentication = 3
+    additional_drivers = 4
+    developer_options = 5
+    ubuntu_pro = 6
+
+
 def get_string_with_no_auth_from_source_entry(entry):
     tmp = copy(entry)
     url_parts = urlsplit(tmp.uri)
@@ -105,7 +115,7 @@ def is_unity_running():
         import dbus
         bus = dbus.SessionBus()
         unity_running = bus.name_has_owner("com.canonical.Unity")
-    except:
+    except Exception as e:
         logging.exception("could not check for Unity dbus service")
     return unity_running
 
@@ -306,10 +316,10 @@ def init_proxy(gsettings=None):
     * then into gconf  (if gconfclient was supplied)
     """
     SYNAPTIC_CONF_FILE = "/root/.synaptic/synaptic.conf"
-    proxy = None
+    proxies = {}
     # generic apt config wins
     if apt_pkg.config.find("Acquire::http::Proxy") != '':
-        proxy = apt_pkg.config.find("Acquire::http::Proxy")
+        proxies["http"] = apt_pkg.config.find("Acquire::http::Proxy")
     # then synaptic
     elif os.path.exists(SYNAPTIC_CONF_FILE):
         cnf = apt_pkg.Configuration()
@@ -319,18 +329,26 @@ def init_proxy(gsettings=None):
             proxy_host = cnf.find("Synaptic::httpProxy")
             proxy_port = str(cnf.find_i("Synaptic::httpProxyPort"))
             if proxy_host and proxy_port:
-                proxy = "http://%s:%s/" % (proxy_host, proxy_port)
+                proxies["http"] = "http://%s:%s/" % (proxy_host, proxy_port)
+    if apt_pkg.config.find("Acquire::https::Proxy") != '':
+        proxies["https"] = apt_pkg.config.find("Acquire::https::Proxy")
+    elif "http" in proxies:
+        proxies["https"] = proxies["http"]
     # if we have a proxy, set it
-    if proxy:
+    if proxies:
         # basic verification
-        if not re.match("http://\w+", proxy):
-            print("proxy '%s' looks invalid" % proxy, file=sys.stderr)
-            return
-        proxy_support = ProxyHandler({"http": proxy})
+        for proxy in proxies.values():
+            if not re.match("https?://\w+", proxy):
+                print("proxy '%s' looks invalid" % proxy, file=sys.stderr)
+                return
+        proxy_support = ProxyHandler(proxies)
         opener = build_opener(proxy_support)
         install_opener(opener)
-        os.putenv("http_proxy", proxy)
-    return proxy
+        if "http" in proxies:
+            os.putenv("http_proxy", proxies["http"])
+        if "https" in proxies:
+            os.putenv("https_proxy", proxies["https"])
+    return proxies
 
 
 def on_battery():
@@ -363,29 +381,27 @@ def on_battery():
 
 def inhibit_sleep():
     """
-    Send a dbus signal to power-manager to not suspend
-    the system, using the freedesktop common interface
+    Send a dbus signal to logind to not suspend the system, it will be
+    released when the return value drops out of scope
     """
     try:
-        import dbus
-        bus = dbus.Bus(dbus.Bus.TYPE_SESSION)
-        devobj = bus.get_object('org.freedesktop.PowerManagement',
-                                '/org/freedesktop/PowerManagement/Inhibit')
-        dev = dbus.Interface(devobj, "org.freedesktop.PowerManagement.Inhibit")
-        cookie = dev.Inhibit('UpdateManager', 'Updating system')
-        return (dev, cookie)
+        from gi.repository import Gio, GLib
+        connection = Gio.bus_get_sync(Gio.BusType.SYSTEM)
+
+        var, fdlist = connection.call_with_unix_fd_list_sync(
+            'org.freedesktop.login1', '/org/freedesktop/login1',
+            'org.freedesktop.login1.Manager', 'Inhibit',
+            GLib.Variant('(ssss)',
+                         ('shutdown:sleep',
+                          'UpdateManager', 'Updating System',
+                          'block')),
+            None, 0, -1, None, None)
+        inhibitor = Gio.UnixInputStream(fd=fdlist.steal_fds()[var[0]])
+
+        return inhibitor
     except Exception:
         #print("could not send the dbus Inhibit signal: %s" % e)
-        return (False, False)
-
-
-def allow_sleep(dev, cookie):
-    """Send a dbus signal to gnome-power-manager to allow a suspending
-    the system"""
-    try:
-        dev.UnInhibit(cookie)
-    except Exception as e:
-        print("could not send the dbus UnInhibit signal: %s" % e)
+        return False
 
 
 def str_to_bool(str):
@@ -503,7 +519,7 @@ def is_port_already_listening(port):
     STATE_LISTENING = '0A'
     # read the data
     with open("/proc/net/tcp") as net_tcp:
-        for line in net_tcp:
+        for line in net_tcp.readlines():
             line = line.strip()
             if not line:
                 continue
