@@ -26,6 +26,7 @@ from gi.repository import Gtk
 from gi.repository import Gdk, GdkX11
 from gi.repository import Gio
 from gi.repository import GLib
+import uaclient.api.u.pro.packages.updates.v1 as ua
 
 GdkX11  # pyflakes
 
@@ -35,11 +36,11 @@ warnings.filterwarnings("ignore", "Accessed deprecated property",
 
 import apt_pkg
 import distro_info
-import json
 import os
 import subprocess
 import sys
 import time
+import threading
 from gettext import gettext as _
 
 import dbus
@@ -228,35 +229,46 @@ class UpdateManager(Gtk.Window):
                                          cancelled_update, error_occurred)
         self._start_pane(pane)
 
+    def _fetch_ua_updates(self):
+        try:
+            self.ua_updates = ua.updates().updates
+        except Exception as e:
+            print("Error running updates end-point: ", e)
+            self.ua_updates = []
+
     def _get_ua_security_status(self):
         self.ua_security_packages = []
-        try:
-            p = subprocess.run(['pro', 'security-status', '--format=json'], stdout=subprocess.PIPE)
-        except OSError:
-            pass
-        else:
-            s = json.loads(p.stdout.decode('utf-8'))
-            for package in s.get('packages', []):
-                if package.get('service_name', '') == 'standard-security':
-                    continue
-                status = package.get('status', '')
-                if (
-                    status == 'pending_attach'
-                    or status == 'pending_enable'
-                    or status == 'upgrade_available'
-                ):
-                    name = package.get('package', '')
-                    version = package.get('version', '')
-                    size = package.get('download_size', 0)
-                    downloadable = status == 'upgrade_available'
-                    self.ua_security_packages.append(
-                        (name, version, size, downloadable)
-                    )
-            self.cache.create_pro_cache(self.ua_security_packages)
+        self.ua_updates = []
+        t = threading.Thread(target=self._fetch_ua_updates, daemon=True)
+        t.start()
+        while t.is_alive():
+            while Gtk.events_pending():
+                Gtk.main_iteration()
+            time.sleep(0.05)
+        for package in self.ua_updates:
+            if (
+                package.provided_by == 'standard-security'
+                or package.provided_by == 'standard-updates'
+            ):
+                continue
+            status = package.status
+            if (
+                status == 'pending_attach'
+                or status == 'pending_enable'
+                or status == 'upgrade_available'
+            ):
+                name = package.package
+                version = package.version
+                size = package.download_size
+                downloadable = status == 'upgrade_available'
+                self.ua_security_packages.append(
+                    (name, version, size, downloadable)
+                )
+        self.cache.create_pro_cache(self.ua_security_packages)
 
     def _make_available_pane(self, install_count, need_reboot=False,
                              cancelled_update=False, error_occurred=False):
-        if install_count != 0 or len(self.ua_security_packages) > 0:
+        if install_count != 0:
             header = None
             desc = None
             if error_occurred:
@@ -275,8 +287,6 @@ class UpdateManager(Gtk.Window):
                 return dist_upgrade
             elif cancelled_update:
                 return StoppedUpdatesDialog(self)
-            elif self.hwe_replacement_packages:
-                return HWEUpgradeDialog(self)
             else:
                 return NoUpdatesDialog(self, error_occurred=error_occurred)
 
