@@ -372,6 +372,9 @@ class UpdatesAvailable(InternalDialog):
             apt_news = self._get_apt_news(
                 "/var/lib/ubuntu-advantage/messages/apt-news"
             )
+        except Exception as e:
+            print("Error running current_news end-point: ", e)
+            apt_news = ""
         if apt_news:
             self.news.get_buffer().set_text(apt_news)
             self.expander_news.set_visible(True)
